@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced;
 
 use Moo;
 
-our $VERSION = '0.000016';
+our $VERSION = '0.000017';
 
 use feature qw( say state );
 
@@ -27,6 +27,7 @@ use WebService::PayPal::PaymentsAdvanced::Response::Authorization;
 use WebService::PayPal::PaymentsAdvanced::Response::Authorization::CreditCard;
 use WebService::PayPal::PaymentsAdvanced::Response::Authorization::PayPal;
 use WebService::PayPal::PaymentsAdvanced::Response::Capture;
+use WebService::PayPal::PaymentsAdvanced::Response::Credit;
 use WebService::PayPal::PaymentsAdvanced::Response::FromHTTP;
 use WebService::PayPal::PaymentsAdvanced::Response::FromRedirect;
 use WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST;
@@ -261,6 +262,7 @@ sub post {
 
     my %class_for_type = (
         A => 'Response::Authorization',
+        C => 'Response::Credit',
         D => 'Response::Capture',
         I => 'Response::Inquiry',
         S => 'Response::Sale',
@@ -274,7 +276,7 @@ sub post {
         $response_class_suffix = $class_for_type{$type};
 
         # Get more specific response classes for CC and PayPal txns.
-        unless ( any { $type eq $_ } ( 'D', 'V' ) ) {
+        unless ( any { $type eq $_ } ( 'C', 'D', 'V' ) ) {
             my $response = $self->_response_for(
                 $response_class_suffix,
                 params => $params
@@ -292,6 +294,20 @@ sub post {
     return $self->_response_for( $response_class_suffix, params => $params );
 }
 
+sub refund_transaction {
+    my $self = shift;
+    state $check = compile( NonEmptyStr, Optional [NonEmptyStr] );
+    my ( $origid, $amount ) = $check->(@_);
+
+    return $self->post(
+        {
+            TRXTYPE => 'C',
+            ORIGID  => $origid,
+            $amount ? ( AMT => $amount ) : ()
+        }
+    );
+}
+
 sub auth_from_credit_card_reference_transaction {
     my $self = shift;
     return $self->_credit_card_reference_transaction( 'A', @_ );
@@ -424,7 +440,7 @@ WebService::PayPal::PaymentsAdvanced - A simple wrapper around the PayPal Paymen
 
 =head1 VERSION
 
-version 0.000016
+version 0.000017
 
 =head1 SYNOPSIS
 
@@ -479,7 +495,7 @@ version 0.000016
 
     # Everything looks good.  Carry on!
 
-print $response->secure_token;
+    print $response->secure_token;
 
 =head1 DESCRIPTION
 
@@ -730,6 +746,12 @@ argument.
     );
     say $response->message;
 
+=head3 refund_transaction( $origid, [$amount] )
+
+Refunds (credits) a previous transaction.  Requires the C<ORIGID> and an
+optional C<AMT>.  If no amount is provided, the entire transaction will be
+refunded.
+
 =head3 inquiry_transaction( $HashRef )
 
 Performs a transaction inquiry on a previously submitted transaction.  Requires
@@ -759,12 +781,16 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Greg Oschwald Mark Fowler Olaf Alders
+=for stopwords Dave Rolsky Greg Oschwald Mark Fowler Olaf Alders
 
 =over 4
 
 =item *
 
+Dave Rolsky <drolsky@maxmind.com>
+
+=item *
+
 Greg Oschwald <goschwald@maxmind.com>
 
 =item *
