@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro;
 
 use Mojolicious::Lite;
 
-our $VERSION = '0.000016';
+our $VERSION = '0.000017';
 
 use feature qw( state );
 
@@ -33,7 +33,8 @@ post '/' => sub {
     }
 
     if ( !$params->{TRXTYPE}
-        || none { $params->{TRXTYPE} eq $_ } ( 'A', 'D', 'I', 'S', 'V', ) ) {
+        || none { $params->{TRXTYPE} eq $_ }
+        ( 'A', 'C', 'D', 'I', 'S', 'V', ) ) {
         $c->render( text => 'Mocked URL not found', status => 404 );
         return;
     }
@@ -170,6 +171,19 @@ post '/' => sub {
         }
     }
 
+    if ( $params->{TRXTYPE} eq 'C' ) {
+        my %return = (
+            CORRELATIONID => $helper->correlationid,
+            PNREF         => $helper->pnref,
+            PPREF         => $helper->ppref,
+            RESPMSG       => 'Approved',
+            RESULT        => 0,
+            TRANSTIME     => $helper->transtime,
+        );
+        _render_response( $c, \%return );
+        return;
+    }
+
     if ( $params->{TRXTYPE} eq 'V' ) {
         my %return = (
             CORRELATIONID => $helper->correlationid,
@@ -235,7 +249,7 @@ WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro - A simple app to enabl
 
 =head1 VERSION
 
-version 0.000016
+version 0.000017
 
 =head1 DESCRIPTION
 
